#!/usr/bin/env perl
#
# Copyright © 2019 Dr. Tobias Quathamer <toddy@debian.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

use strict;
use warnings;

# Set up month names
my @months =
  qw(ژانویه فوریه مارس آوریل مه ژوئن ژوئیه آگوست سپتامبر اکتبر نوامبر دسامبر);

# Split by paragraphs, in order to be able to remove a 'fuzzy' mark.
$/ = "";

while (<>) {

    print;
}
